// DO NOT EDIT -- generated by mk-ops.awk
#if ! defined (octave_vx_cs_cv_h)
#define octave_vx_cs_cv_h 1
#include "octave-config.h"
#include "CColVector.h"
#include "oct-cmplx.h"
#include "dColVector.h"
  extern OCTAVE_API ComplexColumnVector operator + (const Complex&, const ColumnVector&);
  extern OCTAVE_API ComplexColumnVector operator - (const Complex&, const ColumnVector&);
  extern OCTAVE_API ComplexColumnVector operator * (const Complex&, const ColumnVector&);
  extern OCTAVE_API ComplexColumnVector operator / (const Complex&, const ColumnVector&);
#endif
